import kubify.src.core.k8s_utils as module_0


def test_case_0():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_1():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_2():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_3():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_4():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_5():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_6():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_7():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_8():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_9():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass
